# ListLabelsResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**labels** | [**list[Label]**](Label.md) | List of labels. Note that each label resource only contains an &#x60;id&#x60;, &#x60;name&#x60;, &#x60;messageListVisibility&#x60;, &#x60;labelListVisibility&#x60;, and &#x60;type&#x60;. The labels.get method can fetch additional label details. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

